## A Central error handler for express app

## Eeasy Express error handler with the most commun errors

Error-Express-Handler is a easy middleware with build in errors messages for the most commun http errors in an express application. Using this packeges the user no longer have to put the code status and the message for the error

## Getting started

- npm install `npm i error-express-handler` or `yarn add error-express-handler`
- In your express server file, require `errorHandler`

```javascript
const { errorHandler } = require("error-express-handler");
const express = require("express");

//server
const server = expresss();
server.use(express.json());

//use errorHandler middleware here
server.use(errorHandler);

server.listen(port, () => {
  console.log(`\n*** Server running on http://localhost:${port}  ***\n`);
});
```

At this moment you can require `responseStatus` anywhere in your code and use it like in this example:

- example before using `error-express-handler` your code could look similar to:

```

router.delete("/users/:id", async (req, res, next) => {
  const { id } = req.params;
  try {
    const result = await dbHelpers.deleteUserById(id);
    if (result === 1) {
      res.status(200).json({
        message: "Delete user Sucesfully"
      });
    } else {
      res
        .status(404)
        .json({ message: "The server can not find requested resource" });
    }
  } catch (error) {
    res.status(500).json({
      error: `The server has encountered a situation it doesn't know how to handle`
    });
  }
});

```

- Now anywhere in the app where you want to catch errors, you can use responseStus :

```

const { responseStatus } = require("error-express-handler");

router.delete("/users/:id", async (req, res, next) => {
  const { id } = req.params;
  try {
    const result = await dbHelpers.deleteUserById(id);
    if (result === 1) {
      res.status(responseStatus.successful).json({
        message: "Delete user Sucesfully"
      });
    } else {
      next(responseStatus.notFound);
    }
  } catch (error) {
    next(responseStatus.serverError);
  }
});

```

The above would return:

- in case of `next(responseStatus.notFound)`:

```json
{
  "status": "error",
  "code": 404,
  "message": "Resource not found"
}
```

# Contribution

- Got an idea on how to make this package better, feel free to contribute

Follow me on twitter [@iam_nedsoft](https://twitter.com/iam_nedsoft) for more updates
